/******************************************************************
*
* Create Replication File for Gerber/Huber/Washington 2010
*
* Gregory A. Huber
* gregory.huber@yale.edu
* This version: July 2010
*
******************************************************************/

set more off
set memory 150m
graph set eps logo off
graph set ps logo off
graph set ps tmargin 1

/******************************************************************
*
* Load in the merged pre- and post-primary election voter file
* This includes the first round of survey data
*
******************************************************************/
use rawdata\merge_prepost.dta

/******************************************************************
*
* Load in 1st round survey data
*
******************************************************************/

*get rid of first round survey data in voter file, that is now loaded directly in these data.
drop pid7 interest votein2000 vote2000* econforecast inflationperf bushapp congapp 
rename ghwid2 ghwid
joinby ghwid using rawdata\firstroundsurveydataforcompletedsurveyssortedbyghwid.dta, unmatched(both)
tab _merge
rename ghwid ghwid2
drop _merge

/******************************************************************
*
* Load in 3rd round survey data
*
******************************************************************/
sort ghwid2
count
joinby ghwid using rawdata\clinton_survey_rd3_recoded_sortedby_ghwid2, unmatched(both)
tab _merge
count
drop _merge

/******************************************************************
*
* Load in the list of towns that have nobody voting in 2008 primary
*
******************************************************************/
sort town_id
joinby town_id using rawdata\towns_with_no_votes.dta, unmatched(master)
gen townshowsnoturnoutinvoterfile=(_merge==3)
label var townshowsnoturnoutinvoterfile "Town has not reported turnout for 2008"
drop _merge

/******************************************************************
*
* Load in the change of address/deaths data
*
******************************************************************/
sort ghwid2
count
joinby ghwid2 using rawdata\ghwid2_to_badaddressormove.dta
count

label var R_persondead "COA: Person reported dead"
label var R_movedpre "COA: Person reported moving prior to experiment"
label var R_movedpost "COA: Person reported moving after experiment"
label var R_badmailadddress "COA: Bad Mailing address"
label var R_anybad "COA: Dead, Moved, or Bad Mailing Address"

gen R_STRATACOAFILTER=R_movedpre+R_badmailadddress
replace R_STRATACOAFILTER=R_STRATACOAFILTER+R_persondead if strata==3
replace R_STRATACOAFILTER=1 if R_STRATACOAFILTER>1 & R_STRATACOAFILTER~=.
label var R_STRATACOAFILTER "Strata Appropriate Movers/Bad Address/Dead Sample Filter"

*Label variables
label var treat "Sent Mail"

*Original Strata
label define stratalabel 1 "Survey Refused" 2 "Dead #/Wrong #" 3 "Never called" 10 "Surveyed, NO PID" 11 "Strong D" 12 "Weak D" 13 "Lean D" 14 "Indpt" 15 "Lean R" 16 "Weak R" 17 "Strong R"
drop if strata==1 | strata==2
label values strata stratalabel
tab strata, gen(SD_)
drop SD_1

*Strata indicators among those surveyed who expressed a party ID (including independents)
tab strata if strata>10, gen(SDA_)
drop SDA_4

*A Strata counter, which goes from 1-9. This makes the subsequent analysis easier by allowing us to loop over this counter
gen stratactr=strata-2
replace stratactr=stratactr-6 if stratactr>3
label define stratactrlabel 1 "Never called" 2 "Surveyed, NO PID" 3 "Strong D" 4 "Weak D" 5 "Lean D" 6 "Indpt" 7 "Lean R" 8 "Weak R" 9 "Strong R"
label values stratactr stratactrlabel

*A different strata counter, which has the first three categories plus merges all of those surveyed into a single group
gen altstrata=stratactr
replace altstrata=2 if altstrata>=1
label define altstratactrlabel 1 "Never called" 2 "Surveyed"
label values altstrata altstratactrlabel

*Separate treatment indicators by strata
tab stratactr, gen(SI_)
tab stratactr, gen(STI_)
forvalues i = 1(1)9 {
 replace STI_`i'=0 if treat==0
}
label var STI_1 "Treated, Never called"
label var STI_2 "Treated, Surveyed, NO PID"
label var STI_3 "Treated, Strong D"
label var STI_4 "Treated, Weak D"
label var STI_5 "Treated, Lean D"
label var STI_6 "Treated, Indpt"
label var STI_7 "Treated, Lean R"
label var STI_8 "Treated, Weak R"
label var STI_9 "Treated, Strong R"

label var SI_1 "Never called"
label var SI_2 "Surveyed, NO PID"
label var SI_3 "Strong D"
label var SI_4 "Weak D"
label var SI_5 "Lean D"
label var SI_6 "Indpt"
label var SI_7 "Lean R"
label var SI_8 "Weak R"
label var SI_9 "Strong R"
drop SI_1

*All people were initially unaffiliated, so this codes changes.
gen post_unif= (p_cd_party=="U")
label var post_unif "Post-Unaffiliated"
gen post_affil=1-post_unif
label var post_affil "Post-Affiliated with Party"
gen post_dem= (p_cd_party=="D")
label var post_dem "Post-Reg. as Democrat"
gen post_rep= (p_cd_party=="R")
label var post_rep "Post-Reg. as Republican"

gen post_DUR=0
replace post_DUR=1 if (p_cd_party=="D")
replace post_DUR=-1 if (p_cd_party=="R")
label var post_DUR "Post-Reg (-1=R, 0=U, 1=D)"

*Code last election person voted in.
rename vote2008primary voted2008
label var voted2008 "Voted in 2008 primary"

*For towns where nobody voted, set turnout to missing.
tab voted2008, missing
replace voted2008=. if townshowsnoturnoutinvoterfile==1
tab voted2008, missing

*Gender
gen vffemale=(gender=="F")
label var vffemale "Female (voter file)"
gen vfgendermissing=(gender~="F") & (gender~="M")
label var vfgendermissing "Gender missing in voter file"

*Age
label var age "Age, years (voter file)"
gen age2=age^2
label var age2 "Age squared"

*Number of phone numbers at address
gen twophones=newphonect-1
label var twophones "Two phone number at address (voter file)"

*Registration year
gen regyearmissing=(regyear==.)
label var regyearmissing "Year registered missing"
replace regyear=2007 if regyear==.
label var regyear "Year registered, missing=2007 (voter file)"

*Other variables
label var twonames "Two registered people in household (voter file)"
label var voted1996 "Voted in 1996"
label var voted1998 "Voted in 1998"
label var voted2000 "Voted in 2000"
label var voted2002 "Voted in 2002"
label var voted2004 "Voted in 2004"
label var voted2006 "Voted in 2006"

*Here we label variables from the first round of survey data
label var pid7 "Pre-survey Party ID (1=SD, 2=WD, 3=CD, 4=I, 5=CR, 6=WR, 7=SR)"
label var interest "Pre-survey Interest in Primary (2=Very, 1=Somewhat, 0=Not Much)"
label var votein2000 "Pre-survey Report Voting in 2000 (1=yes)"
label var vote2000bush "Pre-survey Report Voting for Bush in 2000 (1=yes)"
label var vote2000gore "Pre-survey Report Voting for Gore in 2000 (1=yes)"
label var econretro "Pre-survey Economy Retrospective Judgement (2=MB, 1=B, 0=Same/DK, -1=W, -2=MW)"
label var unemployment "Pre-survey Unemployment Performance (2=MB, 1=B, 0=Same/DK, -1=W, -2=MW)"
label var bushapp "Pre-survey Bush Approval (2=SA, 1=WA, 0=DK, -1=WD, -2=SD)"
label var congapp "Pre-survey Congress Approval (2=SA, 1=WA, 0=DK, -1=WD, -2=SD)"

*Update label for post-survey variables
label var pt_pid7 "Post-survey Party ID (1=SD, 2=WD, 3=CD, 4=I, 5=CR, 6=WR, 7=SR)"

/******************************************************************
*
* Deal with missing data
*
******************************************************************/

*First, gender. Gender can be missing in the voter file, so update with survey if missing in voter file
gen combined_female=vffemale
replace combined_female=pt_female if pt_female~=.
label var combined_female "Female (1=yes) VF/Survey"

/******************************************************************
*
* Keep appropriate Strata for analysis (partisan leaners, independents, and untreated partisans)
*
******************************************************************/

keep if (strata==13 | strata==14 | strata==15) | (treat==0 & (strata==11 | strata==12 | strata==16 | strata==17))

/******************************************************************
*
* Delete all personally identifying informating
*
******************************************************************/

drop phone ghwid2-interviewed town-dateaccepted phonect-bday regdate newphonect- p_dt_accept ghwid3

save GerberHuberWashington_APSR_AnonymizedReplicationFile.dta, replace

